==> imdb-movie-1.3.3.tgz: package/utils/utils.js <==
let dataService = require('./../services/dataService');
const fs = require('fs');
const kue = require('../kueHandler/kue');


/**
 * Created by renjer on 3/30/18.
 */

/**
 * we must rename movie directory after getting info, so this function should
 * for example if thi function get inception info should return
 * inception (2010) -* 8.8
 * @param movieInfo
 */
function getMovieDirectoryNameByInfo(movieInfo) {
    return movieInfo.title + " (" + movieInfo.year + ")" + " -* " + movieInfo.rating
}

/***
 * for example if name of directory is inception [2010] nolan, this function will return inception
 * @param movieDirectoryName
 */
function extractTitleFromMovieDirectoryName(movieDirectoryName) {
    let splitedMovieDirectoryName = movieDirectoryName.split(" ");
    let finalName;
    splitedMovieDirectoryName.forEach((item) => {
        if (!finalName && (item.includes("1" ) || item.includes("2"))
            &&( item.length == 4 || item.length == 5 || item.length == 6)) {
            finalName = movieDirectoryName.split(item)[0]
        }
        
        
    });
    return finalName || movieDirectoryName

}

function fetchAndSaveMovieInfo(movie, dir) {
    let movieName = extractTitleFromMovieDirectoryName(movie).trim();
    console.log("movie name   : ", movieName);
    return dataService.getMovieInfoFromOurServers(movieName).then((movieInfo) => {
        if (movieName.toLowerCase() != movieInfo.title.toLowerCase()){
            return Promise.reject('movieName and title of fetched movie doesnt match\n'+
            movieName+ "   vs   " +movieInfo.title + "\n\n");
        }
        console.log("movie info downloaded   : ", movie);
        let movieDirName = getMovieDirectoryNameByInfo(movieInfo);
        fs.renameSync(dir + "/" + movie, dir + "/" + movieDirName);
        return dataService.makeFileAndPutSthInIt(movieInfo, dir + "/" + movieDirName)
    }).catch(err => {
        console.log("fetch movie info error   : ", err);
        return Promise.reject();
    })
}
/***
 * get item(movie) of in directory and forEach on them and call  fetchDataSaveFilesAndRenameDirectoryOfMovie()
 */
function getDirectoryNameAndFetchMoviesItem(dir, overWriteAvailableInfo) {
    console.log("get Directory name ... called  : ");
    let moviesArray = fs.readdirSync(dir);
    moviesArray.forEach((movie) => {
        console.log("movie :  : ", movie);
        if (!overWriteAvailableInfo && movie.includes("-*")){
            console.log("movie info saved before  : ", movie);
            return;
        }
        // fetchAndSaveMovieInfo(movie, dir);
        let task = {
            taskTyp: "movieInfo",
            executor: fetchAndSaveMovieInfo.bind(null, movie, dir),
            maxRetries:0
        };
        kue.addTask(task);
        
        
        // movieName.forEach((movieInfo) => {
        //     let movieDirName = utils.getMovieDirectoryNameByInfo(movieInfo);
        //     fs.renameSync(dir + "/" + movie, dir + "/" + movieDirName);
        //     dataService.makeFileAndPutSthInIt(movieInfo, dir + "/" + movieDirName)
        //    
        //    
        // })
    });

}


/***
 * movie item is name of directory of movie, that this function do all thing for movie
 * @param movieItem
 */
function fetchDataSaveFilesAndRenameDirectoryOfMovie(movieItem) {

}


function indexMoviesInfo(dir) {
    let movies =[];
    let items = fs.readdirSync(dir);
    items.forEach(item => {
        const infoPath = dir+"/"+item+"/info.txt";
        let fileExist = fs.existsSync(infoPath);
        // if (item.includes("-*")){
        if (fileExist){
            const movieStr =fs.readFileSync(infoPath);
            let movie = JSON.parse(movieStr)
            movies.push(movie)
            console.log("Movie info added : ", item)
        }
    });

    fs.writeFileSync("../web/src/data/movies.json",JSON.stringify(movies) );
    console.log("Movies synced successfully")
}

function deleteMoviesData() {
    fs.unlinkSync("../web/src/data/movies.json")
}

module.exports = {
    getMovieDirectoryNameByInfo,
    extractTitleFromMovieDirectoryName,
    getDirectoryNameAndFetchMoviesItem,
    fetchDataSaveFilesAndRenameDirectoryOfMovie,
    indexMoviesInfo,
    deleteMoviesData
};

==> imdb-movie-1.3.6.tgz: package/utils/utils.js <==
let dataService = require('./../services/dataService');
const fs = require('fs');
const kue = require('../kueHandler/kue');


/**
 * Created by renjer on 3/30/18.
 */

/**
 * we must rename movie directory after getting info, so this function should
 * for example if thi function get inception info should return
 * inception (2010) -* 8.8
 * @param movieInfo
 */
function getMovieDirectoryNameByInfo(movieInfo) {
    return movieInfo.title + " (" + movieInfo.year + ")" + " -* " + movieInfo.rating
}

/***
 * for example if name of directory is inception [2010] nolan, this function will return inception
 * @param movieDirectoryName
 */
function extractTitleFromMovieDirectoryName(movieDirectoryName) {
    let splitedMovieDirectoryName = movieDirectoryName.split(" ");
    let finalName;
    splitedMovieDirectoryName.forEach((item) => {
        if (!finalName && (item.includes("1" ) || item.includes("2"))
            &&( item.length == 4 || item.length == 5 || item.length == 6)) {
            finalName = movieDirectoryName.split(item)[0]
        }
        
        
    });
    return finalName || movieDirectoryName

}

function fetchAndSaveMovieInfo(movie, dir) {
    let movieName = extractTitleFromMovieDirectoryName(movie).trim();
    console.log("movie name   : ", movieName);
    return dataService.getMovieInfoFromOurServers(movieName).then((movieInfo) => {
        if (movieName.toLowerCase() != movieInfo.title.toLowerCase()){
            return Promise.reject('movieName and title of fetched movie doesnt match\n'+
            movieName+ "   vs   " +movieInfo.title + "\n\n");
        }
        console.log("movie info downloaded   : ", movie);
        let movieDirName = getMovieDirectoryNameByInfo(movieInfo);
        fs.renameSync(dir + "/" + movie, dir + "/" + movieDirName);
        return dataService.makeFileAndPutSthInIt(movieInfo, dir + "/" + movieDirName)
    }).catch(err => {
        console.log("fetch movie info error   : ", err);
        return Promise.reject();
    })
}
/***
 * get item(movie) of in directory and forEach on them and call  fetchDataSaveFilesAndRenameDirectoryOfMovie()
 */
function getDirectoryNameAndFetchMoviesItem(dir, overWriteAvailableInfo) {
    console.log("get Directory name ... called  : ");
    let moviesArray = fs.readdirSync(dir);
    moviesArray.forEach((movie) => {
        console.log("movie :  : ", movie);
        if (!overWriteAvailableInfo && movie.includes("-*")){
            console.log("movie info saved before  : ", movie);
            return;
        }
        // fetchAndSaveMovieInfo(movie, dir);
        let task = {
            taskTyp: "movieInfo",
            executor: fetchAndSaveMovieInfo.bind(null, movie, dir),
            maxRetries:0
        };
        kue.addTask(task);
        
        
        // movieName.forEach((movieInfo) => {
        //     let movieDirName = utils.getMovieDirectoryNameByInfo(movieInfo);
        //     fs.renameSync(dir + "/" + movie, dir + "/" + movieDirName);
        //     dataService.makeFileAndPutSthInIt(movieInfo, dir + "/" + movieDirName)
        //    
        //    
        // })
    });

}


/***
 * movie item is name of directory of movie, that this function do all thing for movie
 * @param movieItem
 */
function fetchDataSaveFilesAndRenameDirectoryOfMovie(movieItem) {

}


function indexMoviesInfo(dir) {
    let movies =[];
    let items = fs.readdirSync(dir);
    items.forEach(item => {
        const infoPath = dir+"/"+item+"/info.txt";
        let fileExist = fs.existsSync(infoPath);
        // if (item.includes("-*")){
        if (fileExist){
            const movieStr =fs.readFileSync(infoPath);
            let movie = JSON.parse(movieStr)
            movies.push(movie)
            console.log("Movie info added : ", item)
        }
    });

    console.log("movies dir : ",__dirname + "/../web/src/data/movies.json" )
    fs.writeFileSync(__dirname + "/../web/src/data/movies.json",JSON.stringify(movies) );
    console.log("Movies synced successfully")
}

function deleteMoviesData() {
    fs.unlinkSync(__dirname + "/../web/src/data/movies.json")
}

module.exports = {
    getMovieDirectoryNameByInfo,
    extractTitleFromMovieDirectoryName,
    getDirectoryNameAndFetchMoviesItem,
    fetchDataSaveFilesAndRenameDirectoryOfMovie,
    indexMoviesInfo,
    deleteMoviesData
};
